@@ -1,21 +1,17 @@
 from __future__ import annotations
-import abc
 import typing as tp
 import re
 
 from ormlambda import Table
 from ormlambda import Column
-from ormlambda.common.interfaces.IQueryCommand import IQuery
 from ormlambda.sql.types import (
     ASTERISK,
     TableType,
     ColumnType,
     AliasType,
 )
-from .interface import IAggregate
-from ormlambda.common.errors import NotKeysInIAggregateError
+from .interface import IClauseInfo
 from ormlambda.sql import ForeignKey
-from ormlambda.sql.table import TableMeta
 from ormlambda.caster import Caster
 
 
@@ -32,30 +28,6 @@ class ReplacePlaceholderError(ValueError):
         return "You cannot use {" + self.placeholder + "} placeholder without using '" + self.attr + "' attribute"
 
 
-class IClauseInfo[T: Table](IQuery):
-    @property
-    @abc.abstractmethod
-    def table(self) -> TableType[T]: ...
-    @property
-    @abc.abstractmethod
-    def alias_clause(self) -> tp.Optional[str]: ...
-    @property
-    @abc.abstractmethod
-    def alias_table(self) -> tp.Optional[str]: ...
-    @property
-    @abc.abstractmethod
-    def column(self) -> str: ...
-    @property
-    @abc.abstractmethod
-    def unresolved_column(self) -> ColumnType: ...
-    @property
-    @abc.abstractmethod
-    def context(self) -> ClauseContextType: ...
-    @property
-    @abc.abstractmethod
-    def dtype[TProp](self) -> tp.Optional[tp.Type[TProp]]: ...
-
-
 class ClauseInfo[T: Table](IClauseInfo[T]):
     _keyRegex: re.Pattern = re.compile(r"{([^{}:]+)}")
 
@@ -363,72 +335,3 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
         if isinstance(data, Column):
             return True
         return False
-
-
-class AggregateFunctionBase[T: Table](ClauseInfo[T], IAggregate):
-    def __init__[TProp: Column](
-        self,
-        table: TableType[T],
-        column: tp.Optional[ColumnType[TProp]] = None,
-        alias_table: tp.Optional[AliasType[ClauseInfo[T]]] = None,
-        alias_clause: tp.Optional[AliasType[ClauseInfo[T]]] = None,
-        context: ClauseContextType = None,
-        keep_asterisk: bool = False,
-        preserve_context: bool = False,
-    ):
-        self._alias_aggregate = alias_clause
-        super().__init__(
-            table=table,
-            column=column,
-            alias_table=alias_table,
-            context=context,
-            keep_asterisk=keep_asterisk,
-            preserve_context=preserve_context,
-        )
-
-    @staticmethod
-    @abc.abstractmethod
-    def FUNCTION_NAME() -> str: ...
-
-    @classmethod
-    def _convert_into_clauseInfo[TypeColumns, TProp](cls, columns: ClauseInfo | ColumnType[TProp], context: ClauseContextType) -> list[ClauseInfo]:
-        type DEFAULT = tp.Literal["default"]
-        type ClusterType = ColumnType | ForeignKey | DEFAULT
-
-        dicc_type: dict[ClusterType, tp.Callable[[ClusterType], ClauseInfo]] = {
-            Column: lambda column: ClauseInfo(column.table, column, context=context),
-            ClauseInfo: lambda column: column,
-            ForeignKey: lambda tbl: ClauseInfo(tbl.tright, tbl.tright, context=context),
-            TableMeta: lambda tbl: ClauseInfo(tbl, tbl, context=context),
-            "default": lambda column: ClauseInfo(table=None, column=column, context=context),
-        }
-        all_clauses: list[ClauseInfo] = []
-        if isinstance(columns, str) or not isinstance(columns, tp.Iterable):
-            columns = (columns,)
-        for value in columns:
-            all_clauses.append(dicc_type.get(type(value), dicc_type["default"])(value))
-
-        return all_clauses
-
-    @tp.override
-    @property
-    def query(self) -> str:
-        wrapped_ci = self.wrapped_clause_info(self)
-        if not self._alias_aggregate:
-            return wrapped_ci
-
-        return ClauseInfo(
-            table=None,
-            column=wrapped_ci,
-            alias_clause=self._alias_aggregate,
-            context=self._context,
-            keep_asterisk=self._keep_asterisk,
-            preserve_context=self._preserve_context,
-        ).query
-
-    def wrapped_clause_info(self, ci: ClauseInfo[T]) -> str:
-        # avoid use placeholder when using IAggregate because no make sense.
-        if self._alias_aggregate and (found := self._keyRegex.findall(self._alias_aggregate)):
-            raise NotKeysInIAggregateError(found)
-
-        return f"{self.FUNCTION_NAME()}({ci._create_query()})"
